/**
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * 
 * Contact Information:
 * beck et al. projects GmbH
 * Theresienhoehe 13
 * 80336 Munich
 * Phone: +49-89-5442530
 * mailto: info@bea.de
 */
package de.bsvrz.sys.funclib.telnet;

/**
 * Kommando das nicht im Menü angezeigt wird.
 * Darf nur in der obersten Menüebene hinter allen "sichtbaren" Einträgen verwendet werden.
 * @author beck et al. projects GmbH
 * @author Martin Hilgers
 * @version $Revision: 1.1 $ / $Date: 2009/02/05 17:49:08 $ / ($Author: Drapp $)
 */
public abstract class HiddenCommand extends Command
{
	private int index = 0;

    /**
     * Kommando für {@link CmdInterpreter}
     * @param desc die Beschreibung
     * @param index Index des Kommandos. Muss eindeutig sein. Es sollte eine Zahl &gt; 100 gewählt werden,
     * 				damit es zu keinen Überschneidungen mit den übrigen Kommandos kommt.
     */
	public HiddenCommand(String desc, int index)
	{
		super(desc, "");
		this.index = index;
	}
	
	/**
	 * @see de.bsvrz.sys.funclib.telnet.Command#getIndex()
	 */
	public int getIndex()
	{
		return index;
	}

}
